@@ -1,4 +1,3 @@
-from core.utils.exceptions import Cdev_Error, Cdev_Warning
 from core.utils.fs_manager import finder
 
 
@@ -19,17 +18,16 @@ class Cdev_FileSystem_Component(Component):
         self.fp = fp
 
     def render(self) -> ComponentModel:
+        """Render this component based on the information in the files at the provided folder path
+
+        Returns:
+            ComponentModel
         """
-        Render this component based on the information in the files at the provided folder path
-        """
-        resources_sorted, references_sorted = finder.parse_folder(
-            self.fp
-        )
+        resources_sorted, references_sorted = finder.parse_folder(self.fp)
         total_component_hash = hasher.hash_list(
             [x.hash for x in resources_sorted] + [x.hash for x in references_sorted]
         )
 
-        
         rv = ComponentModel(
             **{
                 "resources": list(resources_sorted),
